@@ -5,6 +5,8 @@ from .http import make_http_request as make_http_request
 from .http2 import make_http2_request as make_http2_request
 from .http3 import make_http3_request as make_http3_request
 from .lookup import lookup_url as lookup_url
+from .scp import make_scp_request as make_scp_request
+from .sftp import make_sftp_request as make_sftp_request
 from .smtp import make_smtp_request as make_smtp_request
 from .tcp import make_tcp_request as make_tcp_request
 from .udp import make_udp_request as make_udp_request
