@@ -42,7 +42,7 @@ class MercurySyncFTPConnection:
         self._key_path = key_path
         self._ssl_context: ssl.SSLContext | None = None
 
-        self._loop = asyncio.get_event_loop()
+        self._loop: asyncio.AbstractEventLoop | None = None
 
 
         self._dns_lock: dict[str, asyncio.Lock] = defaultdict(asyncio.Lock)
@@ -71,15 +71,8 @@ class MercurySyncFTPConnection:
         self.address_protocol = protocol
         self._is_secured: bool = False
         
-        self._227_re = re.compile(
-            r'(\d+),(\d+),(\d+),(\d+),(\d+),(\d+)', 
-            re.ASCII,
-        )
-
-        self._150_re = re.compile(
-            r"150 .* \((\d+) bytes\)", 
-            re.IGNORECASE | re.ASCII,
-        )
+        self._227_re: re.Pattern = None
+        self._150_re: re.Pattern = None
 
     async def load_file(
         self,
@@ -557,7 +550,7 @@ class MercurySyncFTPConnection:
         ],
         source_path: str | None = None,
         destination_path: str | None = None,
-        data: str | Data | None = None,
+        data: str | Data | File | None = None,
         auth: tuple[str, str, str] = None,
         options: list[str] | None = None,
         chunk_size: int = 8192,
@@ -594,7 +587,6 @@ class MercurySyncFTPConnection:
             
             if timings["connect_start"] is None:
                 timings["connect_start"] = time.monotonic()
-
                 
             (
                 err,
@@ -679,6 +671,21 @@ class MercurySyncFTPConnection:
                     error=err,
                     timings=timings,
                 )
+            
+            if isinstance(data, Data):
+                data: bytes = data.optimized
+
+            elif isinstance(data, File):
+                (
+                    _,
+                    data,
+                    _,
+                ) = data.optimized
+
+
+            elif isinstance(data, str):
+                data = data.encode()
+
 
             result: Any | None = None
 
@@ -1090,7 +1097,7 @@ class MercurySyncFTPConnection:
     async def _create_account(
         self,
         connection: FTPConnection,
-        password: str,
+        password: bytes,
         timings: dict[
             Literal[
                 "request_start",
@@ -1111,7 +1118,7 @@ class MercurySyncFTPConnection:
         if timings['write_start'] is None:
             timings['write_start'] = time.monotonic()
 
-        command = f'ACCT {password}'
+        command = b'ACCT ' + password
         connection.write(command + CRLF)
 
         timings['write_end'] = time.monotonic()
@@ -2979,21 +2986,25 @@ class MercurySyncFTPConnection:
         connection_error: Exception | None = None
 
         if url.address is None:
-            for address_info in url:
+            for address, ip_info in url:
                 try:
                     port = await connection.make_connection(
                         control_url.hostname if control_url else url.hostname, 
-                        address_info,
+                        ip_info,
                         url.port,
                         ssl=self._ssl_context if use_ssl else None,
                         timeout=self.timeouts.connect_timeout,
                     )
 
-                    connection.host = address_info[-1][0]
+                    host, _ = address
+
+                    connection.host = host
                     connection.socket_family = url.family
-                    parsed_url.address = address_info
+                    parsed_url.address = address
                     parsed_url.port = port
 
+                    break
+
                 except Exception as err:
                     connection_error = err
 
@@ -3002,7 +3013,7 @@ class MercurySyncFTPConnection:
             try:
                 await connection.make_connection(
                     control_url.hostname if control_url else url.hostname,
-                    address_info,
+                    ip_info,
                     url.port,
                     ssl=self._ssl_context if use_ssl else None,
                     timeout=self.timeouts.connect_timeout,
