@@ -2,8 +2,10 @@ from .models import URL as URL
 from .models import Auth as Auth
 from .models import Cookies as Cookies
 from .models import Data as Data
+from .models import Directory as Directory
 from .models import Email as Email
 from .models import File as File
+from .models import FileGlob as FileGlob
 from .models import Headers as Headers
 from .models import Mutation as Mutation
 from .models import Params as Params
